<?php 
/**
 * Account Page Controller
 * @category  Controller
 */
class AccountController extends SecureController{
	function __construct(){
		parent::__construct(); 
		$this->tablename = "users";
		$this->soft_delete = true;
		$this->delete_field_name = "user_status";
		$this->delete_field_value = "deleted";
	}
	/**
		* Index Action
		* @return null
		*/
	function index(){
		$db = $this->GetModel();
		$rec_id = $this->rec_id = USER_ID; //get current user id from session
		$db->where ("user_id", $rec_id);
		$tablename = $this->tablename;
		$fields = array("users.user_id", 
			"users.user_email", 
			"users.email_verified_at", 
			"users.user_mobile_number", 
			"users.user_provider", 
			"users.userable_id", 
			"users.userable_type", 
			"users.remember_token", 
			"users.created_at", 
			"users.updated_at", 
			"users.user_role_id", 
			"roles.role_name AS roles_role_name", 
			"users.created_by_admin_id");
		$db->join("roles", "users.user_role_id = roles.role_id", "INNER");
		$user = $db->getOne($tablename , $fields);
		if(!empty($user)){
			$page_title = $this->view->page_title = get_lang('my_account');
			$this->render_view("account/view.php", $user);
		}
		else{
			$this->set_page_error();
			$this->render_view("account/view.php");
		}
	}
	/**
     * Update user account record with formdata
	 * @param $formdata array() from $_POST
     * @return array
     */
	function edit($formdata = null){
		$request = $this->request;
		$db = $this->GetModel();
		$rec_id = $this->rec_id = USER_ID;
		$tablename = $this->tablename;
		 //editable fields
		$fields = $this->fields = array("user_id","user_mobile_number","user_status","userable_id","userable_type","user_role_id","created_by_admin_id");
		if($formdata){
			$postdata = $this->format_request_data($formdata);
			$this->rules_array = array(
				'user_mobile_number' => 'required',
				'user_status' => 'required',
				'userable_id' => 'required',
				'userable_type' => 'required',
				'user_role_id' => 'required',
				'created_by_admin_id' => 'required',
			);
			$this->sanitize_array = array(
				'user_mobile_number' => 'sanitize_string',
				'user_status' => 'sanitize_string',
				'userable_id' => 'sanitize_string',
				'userable_type' => 'sanitize_string',
				'user_role_id' => 'sanitize_string',
				'created_by_admin_id' => 'sanitize_string',
			);
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			if($this->validated()){
				$db->where("users.user_id", $rec_id);;
				$bool = $db->update($tablename, $modeldata);
				$numRows = $db->getRowCount(); //number of affected rows. 0 = no record field updated
				if($bool && $numRows){
					$this->write_to_log("edit", "true");
					$this->set_flash_msg(get_lang('record_updated_successfully'), "success");
					$db->where ("user_id", $rec_id);
					$user = $db->getOne($tablename , "*");
					set_session("user_data", $user);// update session with new user data
					return $this->redirect("account");
				}
				else{
					if($db->getLastError()){
						$this->set_page_error();
						$this->write_to_log("edit", "false");
					}
					elseif(!$numRows){
						//not an error, but no record was updated
						$this->set_flash_msg(get_lang('no_record_updated'), "warning");
						return	$this->redirect("account");
					}
				}
			}
		}
		$db->where("users.user_id", $rec_id);;
		$data = $db->getOne($tablename, $fields);
		$page_title = $this->view->page_title = get_lang('my_account');
		if(!$data){
			$this->set_page_error();
		}
		return $this->render_view("account/edit.php", $data);
	}
	/**
     * Change account email
     * @return BaseView
     */
	function change_email($formdata = null){
		if($formdata){
			$email = trim($formdata['user_email']);
			$db = $this->GetModel();
			$rec_id = $this->rec_id = USER_ID; //get current user id from session
			$tablename = $this->tablename;
			$db->where ("user_id", $rec_id);
			$result = $db->update($tablename, array('user_email' => $email ));
			if($result){
				$this->write_to_log("emailchange", "true");
				$this->set_flash_msg(get_lang('email_address_changed_successfully'), "success");
				$this->redirect("account");
			}
			else{
				$this->set_page_error(get_lang('email_not_changed'));
				$this->write_to_log("emailchange", "false");
			}
		}
		return $this->render_view("account/change_email.php");
	}
}
