<?php 
/**
 * Index Page Controller
 * @category  Controller
 */
class IndexController extends BaseController{
	function __construct(){
		parent::__construct(); 
		$this->tablename = "users";
		$this->soft_delete = true;
		$this->delete_field_name = "user_status";
		$this->delete_field_value = "deleted";
	}
	/**
     * Index Action 
     * @return null
     */
	function index(){
		if(user_login_status() == true){
			$this->redirect(HOME_PAGE);
		}
		else{
			$this->render_view("index/index.php");
		}
	}
	private function login_user($username , $password_text, $rememberme = false){
		$db = $this->GetModel();
		$username = filter_var($username, FILTER_SANITIZE_STRING);
		$db->where("user_email", $username);
		$tablename = $this->tablename;
		$user = $db->getOne($tablename);
		if(!empty($user)){
			//Verify User Password Text With DB Password Hash Value.
			//Uses PHP password_verify() function with default options
			$password_hash = $user['user_password'];
			$this->modeldata['user_password'] = $password_hash; //update the modeldata with the password hash
			if(password_verify($password_text,$password_hash)){
        		unset($user['user_password']); //Remove user password. No need to store it in the session
				set_session("user_data", $user); // Set active user data in a sessions
				$this->write_to_log("userlogin", "true");
				//if Remeber Me, Set Cookie
				if($rememberme == true){
					$sessionkey = time().random_str(20); // Generate a session key for the user
					//Update user session info in database with the session key
					$db->where("user_id", $user['user_id']);
					$res = $db->update($tablename, array("login_session_key" => hash_value($sessionkey)));
					if(!empty($res)){
						set_cookie("login_session_key", $sessionkey); // save user login_session_key in a Cookie
					}
				}
				else{
					clear_cookie("login_session_key");// Clear any previous set cookie
				}
				$redirect_url = get_session("login_redirect_url");// Redirect to user active page
				if(!empty($redirect_url)){
					clear_session("login_redirect_url");
					return $this->redirect($redirect_url);
				}
				else{
					return $this->redirect(HOME_PAGE);
				}
			}
			else{
				//password is not correct
				return $this->login_fail(get_lang('username_or_password_not_correct'));
			}
		}
		else{
			//user is not registered
			return $this->login_fail(get_lang('username_or_password_not_correct'));
		}
	}
	/**
     * Display login page with custom message when login fails
     * @return BaseView
     */
	private function login_fail($page_error = null){
		$this->set_page_error($page_error);
		$this->write_to_log("userlogin", "false");
		$this->render_view("index/login.php");
	}
	/**
     * Login Action
     * If Not $_POST Request, Display Login Form View
     * @return View
     */
	function login($formdata = null){
		if($formdata){
			$modeldata = $this->modeldata = $formdata;
			$username = trim($modeldata['username']);
			$password = $modeldata['password'];
			$rememberme = (!empty($modeldata['rememberme']) ? $modeldata['rememberme'] : false);
			$this->login_user($username, $password, $rememberme);
		}
		else{
			$this->set_page_error(get_lang('invalid_request'));
			$this->render_view("index/login.php");
		}
	}
	/**
     * Insert new record into the user table
	 * @param $formdata array from $_POST
     * @return BaseView
     */
	function register($formdata = null){
		if($formdata){
			$request = $this->request;
			$db = $this->GetModel();
			$tablename = $this->tablename;
			$fields = $this->fields = array("user_id","user_email","user_mobile_number","user_provider","user_password","userable_id","userable_type","remember_token","user_role_id","created_by_admin_id"); //registration fields
			$postdata = $this->format_request_data($formdata);
			$cpassword = $postdata['confirm_password'];
			$password = $postdata['user_password'];
			if($cpassword != $password){
				$this->view->page_error[] = get_lang('your_password_confirmation_is_not_consistent');
			}
			$this->rules_array = array(
				'user_id' => 'required',
				'user_email' => 'required|valid_email',
				'user_mobile_number' => 'required',
				'user_provider' => 'required',
				'user_password' => 'required',
				'userable_id' => 'required',
				'userable_type' => 'required',
				'remember_token' => 'required',
				'user_role_id' => 'required',
				'created_by_admin_id' => 'required',
			);
			$this->sanitize_array = array(
				'user_id' => 'sanitize_string',
				'user_email' => 'sanitize_string',
				'user_mobile_number' => 'sanitize_string',
				'user_provider' => 'sanitize_string',
				'userable_id' => 'sanitize_string',
				'userable_type' => 'sanitize_string',
				'remember_token' => 'sanitize_string',
				'user_role_id' => 'sanitize_string',
				'created_by_admin_id' => 'sanitize_string',
			);
			$this->filter_vals = true; //set whether to remove empty fields
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			$password_text = $modeldata['user_password'];
			//update modeldata with the password hash
			$modeldata['user_password'] = $this->modeldata['user_password'] = password_hash($password_text , PASSWORD_DEFAULT);
			//Check if Duplicate Record Already Exit In The Database
			$db->where("user_email", $modeldata['user_email']);
			if($db->has($tablename)){
				$this->view->page_error[] = $modeldata['user_email'].get_lang('_already_exist_');
			}
			if($this->validated()){
				$rec_id = $this->rec_id = $db->insert($tablename, $modeldata);
				if($rec_id){
					$this->write_to_log("add", "true");
					$this->login_user($modeldata['user_email'] , $password_text);
					return;
				}
				else{
					$this->set_page_error();
					$this->write_to_log("add", "false");
				}
			}
		}
		$page_title = $this->view->page_title = get_lang('add_new_users');
		return $this->render_view("index/register.php");
	}
	/**
     * Logout Action
     * Destroy All Sessions And Cookies
     * @return View
     */
	function logout($arg=null){
		Csrf::cross_check();
		$this->write_to_log("userlogout", "true");
		session_destroy();
		clear_cookie("login_session_key");
		$this->redirect("");
	}
	/**
     * Change User Language
     * @return null
     */
	function change_language($lang){
		set_cookie('lang', $lang);
		$this->redirect(DEFAULT_PAGE);
	}
}
