<?php 
/**
 * Options Page Controller
 * @category  Controller
 */
class OptionsController extends SecureController{
	function __construct(){
		parent::__construct();
		$this->tablename = "options";
	}
	/**
     * List page records
     * @param $fieldname (filter record by a field) 
     * @param $fieldvalue (filter field value)
     * @return BaseView
     */
	function index($fieldname = null , $fieldvalue = null){
		$request = $this->request;
		$db = $this->GetModel();
		$tablename = $this->tablename;
		$fields = array("option_id", 
			"option_name_en", 
			"option_name_ar", 
			"option_preview_img", 
			"option_price", 
			"option_status", 
			"created_by_admin_id", 
			"header_id");
		$pagination = $this->get_pagination(MAX_RECORD_COUNT); // get current pagination e.g array(page_number, page_limit)
		//search table record
		if(!empty($request->search)){
			$text = trim($request->search); 
			$search_condition = "(
				options.option_id LIKE ? OR 
				options.option_name_en LIKE ? OR 
				options.option_name_ar LIKE ? OR 
				options.option_preview_img LIKE ? OR 
				options.option_price LIKE ? OR 
				options.option_status LIKE ? OR 
				options.created_by_admin_id LIKE ? OR 
				options.header_id LIKE ?
			)";
			$search_params = array(
				"%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%"
			);
			//setting search conditions
			$db->where($search_condition, $search_params);
			 //template to use when ajax search
			$this->view->search_template = "options/search.php";
		}
		if(!empty($request->orderby)){
			$orderby = $request->orderby;
			$ordertype = (!empty($request->ordertype) ? $request->ordertype : ORDER_TYPE);
			$db->orderBy($orderby, $ordertype);
		}
		else{
			$db->orderBy("options.option_id", ORDER_TYPE);
		}
		if($fieldname){
			$db->where($fieldname , $fieldvalue); //filter by a single field name
		}
		$tc = $db->withTotalCount();
		$records = $db->get($tablename, $pagination, $fields);
		$records_count = count($records);
		$total_records = intval($tc->totalCount);
		$page_limit = $pagination[1];
		$total_pages = ceil($total_records / $page_limit);
		$data = new stdClass;
		$data->records = $records;
		$data->record_count = $records_count;
		$data->total_records = $total_records;
		$data->total_page = $total_pages;
		if($db->getLastError()){
			$this->set_page_error();
		}
		$page_title = $this->view->page_title = get_lang('options');
		$this->view->report_filename = date('Y-m-d') . '-' . $page_title;
		$this->view->report_title = $page_title;
		$this->view->report_layout = "report_layout.php";
		$this->view->report_paper_size = "A4";
		$this->view->report_orientation = "portrait";
		$this->render_view("options/list.php", $data); //render the full page
	}
// No View Function Generated Because No Field is Defined as the Primary Key on the Database Table
	/**
     * Insert new record to the database table
	 * @param $formdata array() from $_POST
     * @return BaseView
     */
	function add($formdata = null){
		if($formdata){
			$db = $this->GetModel();
			$tablename = $this->tablename;
			$request = $this->request;
			//fillable fields
			$fields = $this->fields = array("option_id","option_name_en","option_name_ar","option_preview_img","option_price","option_status","created_by_admin_id","header_id");
			$postdata = $this->format_request_data($formdata);
			$this->rules_array = array(
				'option_id' => 'required',
				'option_name_en' => 'required',
				'option_name_ar' => 'required',
				'option_preview_img' => 'required',
				'option_price' => 'required|numeric',
				'option_status' => 'required',
				'created_by_admin_id' => 'required',
				'header_id' => 'required',
			);
			$this->sanitize_array = array(
				'option_id' => 'sanitize_string',
				'option_name_en' => 'sanitize_string',
				'option_name_ar' => 'sanitize_string',
				'option_preview_img' => 'sanitize_string',
				'option_price' => 'sanitize_string',
				'option_status' => 'sanitize_string',
				'created_by_admin_id' => 'sanitize_string',
				'header_id' => 'sanitize_string',
			);
			$this->filter_vals = true; //set whether to remove empty fields
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			if($this->validated()){
				$rec_id = $this->rec_id = $db->insert($tablename, $modeldata);
				if($rec_id){
					$this->set_flash_msg(get_lang('record_added_successfully'), "success");
					return	$this->redirect("options");
				}
				else{
					$this->set_page_error();
				}
			}
		}
		$page_title = $this->view->page_title = get_lang('add_new_options');
		$this->render_view("options/add.php");
	}
// No Edit Function Generated Because No Field is Defined as the Primary Key
// No Delete Function Generated Because No Field is Defined as the Primary Key on the Database Table/View
}
