<?php 
/**
 * Orders Page Controller
 * @category  Controller
 */
class OrdersController extends SecureController{
	function __construct(){
		parent::__construct();
		$this->tablename = "orders";
	}
	/**
     * List page records
     * @param $fieldname (filter record by a field) 
     * @param $fieldvalue (filter field value)
     * @return BaseView
     */
	function index($fieldname = null , $fieldvalue = null){
		$request = $this->request;
		$db = $this->GetModel();
		$tablename = $this->tablename;
		$fields = array("orders.order_id", 
			"orders.customer_id", 
			"customers.customer_full_name AS customers_customer_full_name", 
			"orders.driver_id", 
			"drivers.driver_full_name AS drivers_driver_full_name", 
			"orders.address_id", 
			"customer_addresses.address_name AS customer_addresses_address_name", 
			"orders.delivery_charge_option_id", 
			"delivery_charge_options.delivery_charge_option_name_en AS delivery_charge_options_delivery_charge_option_name_en", 
			"orders.order_total", 
			"orders.order_type", 
			"orders.order_status", 
			"orders.created_at");
		$pagination = $this->get_pagination(MAX_RECORD_COUNT); // get current pagination e.g array(page_number, page_limit)
		//search table record
		if(!empty($request->search)){
			$text = trim($request->search); 
			$search_condition = "(
				orders.customer_id LIKE ? OR 
				orders.order_delivery_charge LIKE ? OR 
				orders.order_expected_arrival_at LIKE ?
			)";
			$search_params = array(
				"%$text%","%$text%","%$text%"
			);
			//setting search conditions
			$db->where($search_condition, $search_params);
			 //template to use when ajax search
			$this->view->search_template = "orders/search.php";
		}
		$db->join("customers", "orders.customer_id = customers.user_id", "INNER");
		$db->join("drivers", "orders.driver_id = drivers.user_id", "INNER");
		$db->join("customer_addresses", "orders.address_id = customer_addresses.address_id", "INNER");
		$db->join("delivery_charge_options", "orders.delivery_charge_option_id = delivery_charge_options.delivery_charge_option_id", "INNER");
		if(!empty($request->orderby)){
			$orderby = $request->orderby;
			$ordertype = (!empty($request->ordertype) ? $request->ordertype : ORDER_TYPE);
			$db->orderBy($orderby, $ordertype);
		}
		else{
			$db->orderBy("orders.order_id", ORDER_TYPE);
		}
		if($fieldname){
			$db->where($fieldname , $fieldvalue); //filter by a single field name
		}
		$tc = $db->withTotalCount();
		$records = $db->get($tablename, $pagination, $fields);
		$records_count = count($records);
		$total_records = intval($tc->totalCount);
		$page_limit = $pagination[1];
		$total_pages = ceil($total_records / $page_limit);
		$data = new stdClass;
		$data->records = $records;
		$data->record_count = $records_count;
		$data->total_records = $total_records;
		$data->total_page = $total_pages;
		//list of record id for audit trail
		$this->rec_id = array_column($records, "order_id");
		$this->write_to_log("list", "true");
		if($db->getLastError()){
			$this->set_page_error();
			$this->write_to_log("list", "false");
		}
		$page_title = $this->view->page_title = get_lang('orders');
		$this->view->report_filename = date('Y-m-d') . '-' . $page_title;
		$this->view->report_title = $page_title;
		$this->view->report_layout = "report_layout.php";
		$this->view->report_paper_size = "A4";
		$this->view->report_orientation = "portrait";
		$this->render_view("orders/list.php", $data); //render the full page
	}
	/**
     * View record detail 
	 * @param $rec_id (select record by table primary key) 
     * @param $value value (select record by value of field name(rec_id))
     * @return BaseView
     */
	function view($rec_id = null, $value = null){
		$request = $this->request;
		$db = $this->GetModel();
		$rec_id = $this->rec_id = urldecode($rec_id);
		$tablename = $this->tablename;
		$fields = array("orders.order_id", 
			"orders.country_id", 
			"countries.country_name_en AS countries_country_name_en", 
			"orders.customer_id", 
			"customers.customer_full_name AS customers_customer_full_name", 
			"orders.order_type", 
			"orders.driver_id", 
			"drivers.driver_full_name AS drivers_driver_full_name", 
			"orders.address_id", 
			"customer_addresses.address_name AS customer_addresses_address_name", 
			"orders.delivery_charge_option_id", 
			"delivery_charge_options.delivery_charge_option_name_en AS delivery_charge_options_delivery_charge_option_name_en", 
			"orders.order_subtotal", 
			"orders.order_delivery_charge", 
			"orders.order_total", 
			"orders.order_status", 
			"orders.customer_note", 
			"orders.admin_note", 
			"orders.created_at", 
			"orders.updated_at");
		if($value){
			$db->where($rec_id, urldecode($value)); //select record based on field name
		}
		else{
			$db->where("orders.order_id", $rec_id);; //select record based on primary key
		}
		$db->join("countries", "orders.country_id = countries.country_id", "INNER");
		$db->join("customers", "orders.customer_id = customers.user_id", "INNER");
		$db->join("drivers", "orders.driver_id = drivers.user_id", "INNER");
		$db->join("customer_addresses", "orders.address_id = customer_addresses.address_id", "INNER");
		$db->join("delivery_charge_options", "orders.delivery_charge_option_id = delivery_charge_options.delivery_charge_option_id", "INNER");  
		$record = $db->getOne($tablename, $fields );
		if($record){
			$this->write_to_log("view", "true");
			$page_title = $this->view->page_title = get_lang('view_orders');
		$this->view->report_filename = date('Y-m-d') . '-' . $page_title;
		$this->view->report_title = $page_title;
		$this->view->report_layout = "report_layout.php";
		$this->view->report_paper_size = "A4";
		$this->view->report_orientation = "portrait";
		}
		else{
			if($db->getLastError()){
				$this->set_page_error();
			}
			else{
				$this->set_page_error(get_lang('no_record_found'));
			}
			$this->write_to_log("view", "false");
		}
		return $this->render_view("orders/view.php", $record);
	}
}
